Learn R Programming

mlmhelpr (version 0.1.1)

r2_pve: Proportion of variance explained

Description

r2_pve calculates the proportional reduction in variance explained (PVE) by adding variables to a prior, nested model. The PVE is considered a local effect size estimate (Peugh, 2010; Raudenbush & Bryk, 2002).

Usage

r2_pve(model1, model2 = NULL)

Value

Data frame containing the proportion of variance explained at each level

Arguments

model1

Previous model, produced using the lme4::lmer() function. Usually, this is the null or unconditional model.

model2

Current model, produced using the lme4::lmer() function.

References

peugh2010mlmhelpr

raudenbush2002mlmhelpr

Examples

Run this code
fit1 <- lme4::lmer(mathach ~ 1 + (1|id), data=hsb, REML=FALSE)
fit2 <- lme4::lmer(mathach ~ 1 + ses + (1|id), data=hsb, REML=FALSE)

r2_pve(fit1, fit2)

Run the code above in your browser using DataLab