r2_pve calculates the proportional reduction in variance explained (PVE) by adding variables to a prior, nested model. The PVE is considered a local effect size estimate (Peugh, 2010; Raudenbush & Bryk, 2002).
Usage
r2_pve(model1, model2 = NULL)
Value
Data frame containing the proportion of variance explained at each level
Arguments
model1
Previous model, produced using the lme4::lmer() function. Usually, this is the null or unconditional model.
model2
Current model, produced using the lme4::lmer() function.